@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALACASTEXPRESSION_H__
-#define __VALACASTEXPRESSION_H__
+#ifndef __VALA_VALACASTEXPRESSION_H__
+#define __VALA_VALACASTEXPRESSION_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -51,11 +51,13 @@ struct _ValaCastExpressionClass {
 	ValaExpressionClass parent;
 };
 
-ValaCastExpression* vala_cast_expression_new (ValaExpression* _inner, ValaTypeReference* type, ValaSourceReference* source);
+ValaCastExpression* vala_cast_expression_new (ValaExpression* inner, ValaTypeReference* type_reference, ValaSourceReference* source_reference, gboolean is_silent_cast);
 ValaExpression* vala_cast_expression_get_inner (ValaCastExpression* self);
 void vala_cast_expression_set_inner (ValaCastExpression* self, ValaExpression* value);
 ValaTypeReference* vala_cast_expression_get_type_reference (ValaCastExpression* self);
 void vala_cast_expression_set_type_reference (ValaCastExpression* self, ValaTypeReference* value);
+gboolean vala_cast_expression_get_is_silent_cast (ValaCastExpression* self);
+void vala_cast_expression_set_is_silent_cast (ValaCastExpression* self, gboolean value);
 GType vala_cast_expression_get_type (void);
 
 G_END_DECLS
