@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,14 +20,13 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include "valaforstatement.h"
+#include <vala/valaforstatement.h>
 #include <gee/arraylist.h>
 #include <gee/list.h>
 #include <gee/readonlycollection.h>
 #include <vala/valaexpression.h>
 #include <vala/valablock.h>
 #include <vala/valasourcereference.h>
-#include <vala/valaforstatement.h>
 #include <vala/valacodevisitor.h>
 
 struct _ValaForStatementPrivate {
@@ -57,8 +56,7 @@ static void vala_for_statement_dispose (GObject * obj);
  * @param source_reference reference to source code
  * @return                 newly created for statement
  */
-ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference)
-{
+ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock* body, ValaSourceReference* source_reference) {
 	GParameter * __params;
 	GParameter * __params_it;
 	ValaForStatement * self;
@@ -85,8 +83,7 @@ ValaForStatement* vala_for_statement_new (ValaExpression* condition, ValaBlock*
  *
  * @param init an initializer expression
  */
-void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init)
-{
+void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression* init) {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (init));
 	vala_code_node_set_parent_node (VALA_CODE_NODE (init), VALA_CODE_NODE (self));
@@ -99,10 +96,9 @@ void vala_for_statement_add_initializer (ValaForStatement* self, ValaExpression*
  *
  * @return initializer list
  */
-GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self)
-{
+GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->initializer)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->initializer)));
 }
 
 
@@ -111,8 +107,7 @@ GeeCollection* vala_for_statement_get_initializer (ValaForStatement* self)
  *
  * @param iter an iterator expression
  */
-void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter)
-{
+void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* iter) {
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
 	g_return_if_fail (VALA_IS_EXPRESSION (iter));
 	vala_code_node_set_parent_node (VALA_CODE_NODE (iter), VALA_CODE_NODE (self));
@@ -125,17 +120,15 @@ void vala_for_statement_add_iterator (ValaForStatement* self, ValaExpression* it
  *
  * @return iterator
  */
-GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self)
-{
+GeeCollection* vala_for_statement_get_iterator (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
-	return GEE_COLLECTION (gee_read_only_collection_new (g_object_ref, g_object_unref, GEE_COLLECTION (self->priv->iterator)));
+	return GEE_COLLECTION (gee_read_only_collection_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, GEE_COLLECTION (self->priv->iterator)));
 }
 
 
-static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor)
-{
+static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
 	ValaForStatement * self;
-	self = ((ValaForStatement*) base);
+	self = VALA_FOR_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
 	{
 		GeeList* init_expr_collection;
@@ -176,10 +169,9 @@ static void vala_for_statement_real_accept (ValaCodeNode* base, ValaCodeVisitor*
 }
 
 
-static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node)
-{
+static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* old_node, ValaCodeNode* new_node) {
 	ValaForStatement * self;
-	self = ((ValaForStatement*) base);
+	self = VALA_FOR_STATEMENT (base);
 	g_return_if_fail (VALA_IS_CODE_NODE (old_node));
 	g_return_if_fail (VALA_IS_CODE_NODE (new_node));
 	if (VALA_CODE_NODE (vala_for_statement_get_condition (self)) == old_node) {
@@ -189,11 +181,11 @@ static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* o
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (((GeeCollection*) self->priv->initializer)); i++) {
-			ValaExpression* __temp2;
-			gboolean __temp3;
-			__temp2 = NULL;
-			if ((__temp3 = VALA_CODE_NODE ((__temp2 = gee_list_get (((GeeList*) self->priv->initializer), i))) == old_node, (__temp2 == NULL ? NULL : (__temp2 = (g_object_unref (__temp2), NULL))), __temp3)) {
+		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->initializer)); i++) {
+			ValaExpression* _tmp0;
+			gboolean _tmp1;
+			_tmp0 = NULL;
+			if ((_tmp1 = VALA_CODE_NODE ((_tmp0 = gee_list_get (((GeeList*) self->priv->initializer), i))) == old_node, (_tmp0 == NULL ? NULL : (_tmp0 = (g_object_unref (_tmp0), NULL))), _tmp1)) {
 				gee_list_set (((GeeList*) self->priv->initializer), i, VALA_EXPRESSION (new_node));
 				return;
 			}
@@ -202,11 +194,11 @@ static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* o
 	{
 		gint i;
 		i = 0;
-		for (i = 0; i < gee_collection_get_size (((GeeCollection*) self->priv->iterator)); i++) {
-			ValaExpression* __temp4;
-			gboolean __temp5;
-			__temp4 = NULL;
-			if ((__temp5 = VALA_CODE_NODE ((__temp4 = gee_list_get (((GeeList*) self->priv->iterator), i))) == old_node, (__temp4 == NULL ? NULL : (__temp4 = (g_object_unref (__temp4), NULL))), __temp5)) {
+		for (i = 0; i < gee_collection_get_size (GEE_COLLECTION (self->priv->iterator)); i++) {
+			ValaExpression* _tmp2;
+			gboolean _tmp3;
+			_tmp2 = NULL;
+			if ((_tmp3 = VALA_CODE_NODE ((_tmp2 = gee_list_get (((GeeList*) self->priv->iterator), i))) == old_node, (_tmp2 == NULL ? NULL : (_tmp2 = (g_object_unref (_tmp2), NULL))), _tmp3)) {
 				gee_list_set (((GeeList*) self->priv->iterator), i, VALA_EXPRESSION (new_node));
 				return;
 			}
@@ -215,44 +207,39 @@ static void vala_for_statement_real_replace (ValaCodeNode* base, ValaCodeNode* o
 }
 
 
-ValaExpression* vala_for_statement_get_condition (ValaForStatement* self)
-{
+ValaExpression* vala_for_statement_get_condition (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
 	return self->priv->_condition;
 }
 
 
-void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value)
-{
-	ValaExpression* __temp7;
+void vala_for_statement_set_condition (ValaForStatement* self, ValaExpression* value) {
+	ValaExpression* _tmp1;
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	__temp7 = NULL;
-	self->priv->_condition = (__temp7 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), __temp7);
+	_tmp1 = NULL;
+	self->priv->_condition = (_tmp1 = g_object_ref (value), (self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL))), _tmp1);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_condition), VALA_CODE_NODE (self));
 }
 
 
-ValaBlock* vala_for_statement_get_body (ValaForStatement* self)
-{
+ValaBlock* vala_for_statement_get_body (ValaForStatement* self) {
 	g_return_val_if_fail (VALA_IS_FOR_STATEMENT (self), NULL);
 	return self->priv->_body;
 }
 
 
-void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value)
-{
-	ValaBlock* __temp10;
-	ValaBlock* __temp9;
+void vala_for_statement_set_body (ValaForStatement* self, ValaBlock* value) {
+	ValaBlock* _tmp2;
+	ValaBlock* _tmp1;
 	g_return_if_fail (VALA_IS_FOR_STATEMENT (self));
-	__temp10 = NULL;
-	__temp9 = NULL;
-	self->priv->_body = (__temp10 = (__temp9 = value, (__temp9 == NULL ? NULL : g_object_ref (__temp9))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), __temp10);
+	_tmp2 = NULL;
+	_tmp1 = NULL;
+	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
 	vala_code_node_set_parent_node (VALA_CODE_NODE (self->priv->_body), VALA_CODE_NODE (self));
 }
 
 
-static void vala_for_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec)
-{
+static void vala_for_statement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (object);
 	switch (property_id) {
@@ -262,12 +249,14 @@ static void vala_for_statement_get_property (GObject * object, guint property_id
 		case VALA_FOR_STATEMENT_BODY:
 		g_value_set_object (value, vala_for_statement_get_body (self));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_for_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec)
-{
+static void vala_for_statement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
 	ValaForStatement * self;
 	self = VALA_FOR_STATEMENT (object);
 	switch (property_id) {
@@ -277,12 +266,14 @@ static void vala_for_statement_set_property (GObject * object, guint property_id
 		case VALA_FOR_STATEMENT_BODY:
 		vala_for_statement_set_body (self, g_value_get_object (value));
 		break;
+		default:
+		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
+		break;
 	}
 }
 
 
-static void vala_for_statement_class_init (ValaForStatementClass * klass)
-{
+static void vala_for_statement_class_init (ValaForStatementClass * klass) {
 	vala_for_statement_parent_class = g_type_class_peek_parent (klass);
 	g_type_class_add_private (klass, sizeof (ValaForStatementPrivate));
 	G_OBJECT_CLASS (klass)->get_property = vala_for_statement_get_property;
@@ -290,43 +281,35 @@ static void vala_for_statement_class_init (ValaForStatementClass * klass)
 	G_OBJECT_CLASS (klass)->dispose = vala_for_statement_dispose;
 	VALA_CODE_NODE_CLASS (klass)->accept = vala_for_statement_real_accept;
 	VALA_CODE_NODE_CLASS (klass)->replace = vala_for_statement_real_replace;
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "foo", "bar", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
-	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "foo", "bar", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_CONDITION, g_param_spec_object ("condition", "condition", "condition", VALA_TYPE_EXPRESSION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
+	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_FOR_STATEMENT_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
 }
 
 
-static void vala_for_statement_vala_statement_interface_init (ValaStatementIface * iface)
-{
+static void vala_for_statement_vala_statement_interface_init (ValaStatementIface * iface) {
 	vala_for_statement_vala_statement_parent_iface = g_type_interface_peek_parent (iface);
 }
 
 
-static void vala_for_statement_init (ValaForStatement * self)
-{
+static void vala_for_statement_init (ValaForStatement * self) {
 	self->priv = VALA_FOR_STATEMENT_GET_PRIVATE (self);
-	self->priv->initializer = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
-	self->priv->iterator = GEE_LIST (gee_array_list_new (g_object_ref, g_object_unref, g_direct_equal));
+	self->priv->initializer = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
+	self->priv->iterator = GEE_LIST (gee_array_list_new (VALA_TYPE_EXPRESSION, ((GBoxedCopyFunc) g_object_ref), g_object_unref, g_direct_equal));
 }
 
 
-static void vala_for_statement_dispose (GObject * obj)
-{
+static void vala_for_statement_dispose (GObject * obj) {
 	ValaForStatement * self;
-	ValaForStatementClass * klass;
-	GObjectClass * parent_class;
 	self = VALA_FOR_STATEMENT (obj);
 	(self->priv->initializer == NULL ? NULL : (self->priv->initializer = (g_object_unref (self->priv->initializer), NULL)));
 	(self->priv->iterator == NULL ? NULL : (self->priv->iterator = (g_object_unref (self->priv->iterator), NULL)));
 	(self->priv->_condition == NULL ? NULL : (self->priv->_condition = (g_object_unref (self->priv->_condition), NULL)));
 	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
-	klass = VALA_FOR_STATEMENT_CLASS (g_type_class_peek (VALA_TYPE_FOR_STATEMENT));
-	parent_class = G_OBJECT_CLASS (g_type_class_peek_parent (klass));
-	parent_class->dispose (obj);
+	G_OBJECT_CLASS (vala_for_statement_parent_class)->dispose (obj);
 }
 
 
-GType vala_for_statement_get_type (void)
-{
+GType vala_for_statement_get_type (void) {
 	static GType vala_for_statement_type_id = 0;
 	if (G_UNLIKELY (vala_for_statement_type_id == 0)) {
 		static const GTypeInfo g_define_type_info = { sizeof (ValaForStatementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_for_statement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaForStatement), 0, (GInstanceInitFunc) vala_for_statement_init };
