@@ -5,7 +5,7 @@
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 2.1 of the License, or (at your option) any later version.
 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -20,8 +20,8 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#ifndef __VALAPARSER_H__
-#define __VALAPARSER_H__
+#ifndef __VALA_VALAPARSER_H__
+#define __VALA_VALAPARSER_H__
 
 #include <glib.h>
 #include <glib-object.h>
@@ -60,6 +60,7 @@ void vala_parser_parse (ValaParser* self, ValaCodeContext* context);
 void vala_parser_push_comment (ValaParser* self, const char* comment_item, gboolean file_comment);
 char* vala_parser_pop_comment (ValaParser* self);
 void vala_parser_parse_file (ValaParser* self, ValaSourceFile* source_file);
+ValaParser* vala_parser_new (void);
 GType vala_parser_get_type (void);
 
 G_END_DECLS
